@@ -29,7 +29,6 @@
 
 
 char alsa_dev[64] = "default";
-enum aufmt alsa_sample_format = AUFMT_S16LE;
 
 static struct ausrc *ausrc;
 static struct auplay *auplay;
@@ -146,24 +145,13 @@ static int alsa_init(void)
 	struct pl val;
 	int err;
 
+	/* XXX: remove check later */
 	if (0 == conf_get(conf_cur(), "alsa_sample_format", &val)) {
 
-		if (0 == pl_strcasecmp(&val, "s16")) {
-			alsa_sample_format = AUFMT_S16LE;
-		}
-		else if (0 == pl_strcasecmp(&val, "float")) {
-			alsa_sample_format = AUFMT_FLOAT;
-		}
-		else if (0 == pl_strcasecmp(&val, "s24_3le")) {
-			alsa_sample_format = AUFMT_S24_3LE;
-		}
-		else {
-			warning("alsa: unknown sample format '%r'\n", &val);
-			return EINVAL;
-		}
+		warning("alsa: alsa_sample_format is deprecated"
+			" -- use ausrc_format or auplay_format instead\n");
 
-		info("alsa: configured sample format `%s'\n",
-		     aufmt_name(alsa_sample_format));
+		(void)val;
 	}
 
 	err  = ausrc_register(&ausrc, baresip_ausrcl(),
