@@ -18,10 +18,10 @@ int  audiosess_alloc(struct audiosess_st **stp,
 void audiosess_interrupt(bool interrupted);
 
 
-int audiounit_player_alloc(struct auplay_st **stp, struct auplay *ap,
+int audiounit_player_alloc(struct auplay_st **stp, const struct auplay *ap,
 			   struct auplay_prm *prm, const char *device,
 			   auplay_write_h *wh, void *arg);
-int audiounit_recorder_alloc(struct ausrc_st **stp, struct ausrc *as,
+int audiounit_recorder_alloc(struct ausrc_st **stp, const struct ausrc *as,
 			     struct media_ctx **ctx,
 			     struct ausrc_prm *prm, const char *device,
 			     ausrc_read_h *rh, ausrc_error_h *errh, void *arg);
