@@ -40,6 +40,7 @@ struct gtk_mod {
 	bool run;
 	bool contacts_inited;
 	bool accounts_inited;
+	struct message_lsnr *message;
 	struct mqueue *mq;
 	GApplication *app;
 	GtkStatusIcon *status_icon;
@@ -181,6 +182,7 @@ static void menu_on_presence_set(GtkMenuItem *item, struct gtk_mod *mod)
 }
 
 
+#ifdef USE_NOTIFICATIONS
 static void menu_on_incoming_call_answer(GtkMenuItem *menuItem,
 		struct gtk_mod *mod)
 {
@@ -197,6 +199,7 @@ static void menu_on_incoming_call_reject(GtkMenuItem *menuItem,
 	denotify_incoming_call(mod, call);
 	mqueue_push(mod->mq, MQ_HANGUP, call);
 }
+#endif
 
 
 static GtkMenuItem *accounts_menu_add_item(struct gtk_mod *mod,
@@ -493,9 +496,11 @@ static void ua_event_handler(struct ua *ua,
 		accounts_menu_set_status(mod, ua, ev);
 		break;
 
+#ifdef USE_NOTIFICATIONS
 	case UA_EVENT_CALL_INCOMING:
 		notify_incoming_call(mod, call);
 		break;
+#endif
 
 	case UA_EVENT_CALL_CLOSED:
 		win = get_call_window(mod, call);
@@ -986,9 +991,11 @@ static int module_init(void)
 	if (err)
 		return err;
 
-	aufilt_register(&vumeter);
+	aufilt_register(baresip_aufiltl(), &vumeter);
+
 #ifdef USE_NOTIFICATIONS
-	err = message_init(message_handler, &mod_obj);
+	err = message_listen(&mod_obj.message, baresip_message(),
+			     message_handler, &mod_obj);
 	if (err) {
 		warning("gtk: message_init failed (%m)\n", err);
 		return err;
@@ -1021,7 +1028,7 @@ static int module_close(void)
 		pthread_join(mod_obj.thread, NULL);
 	mod_obj.mq = mem_deref(mod_obj.mq);
 	aufilt_unregister(&vumeter);
-	message_close();
+	mod_obj.message = mem_deref(mod_obj.message);
 
 #ifdef USE_LIBNOTIFY
 	if (notify_is_initted())
