@@ -13,6 +13,11 @@
 #include "sdes.h"
 
 
+/*
+ * NOTE: this module is deprecated, please use the 'srtp' module instead.
+ */
+
+
 struct menc_st {
 	/* one SRTP session per media line */
 	uint8_t key_tx[32];  /* 32 for alignment, only 30 used */
@@ -431,6 +436,7 @@ static struct menc menc_srtp_mandf = {
 
 static int mod_srtp_init(void)
 {
+	struct list *mencl = baresip_mencl();
 	err_status_t err;
 
 	err = srtp_init();
@@ -440,9 +446,9 @@ static int mod_srtp_init(void)
 		return ENOSYS;
 	}
 
-	menc_register(&menc_srtp_opt);
-	menc_register(&menc_srtp_mand);
-	menc_register(&menc_srtp_mandf);
+	menc_register(mencl, &menc_srtp_opt);
+	menc_register(mencl, &menc_srtp_mand);
+	menc_register(mencl, &menc_srtp_mandf);
 
 	return 0;
 }
