@@ -37,7 +37,7 @@ static struct {
 	struct play *play;
 	struct message_lsnr *message;
 	bool bell;
-
+	bool ringback_disabled;	      /**< no ringback on sip 180 respons */
 	struct tmr tmr_redial;        /**< Timer for auto-reconnect       */
 	uint32_t redial_delay;        /**< Redial delay in [seconds]      */
 	uint32_t redial_attempts;     /**< Number of re-dial attempts     */
@@ -376,6 +376,8 @@ static int create_ua(struct re_printf *pf, void *arg)
 
 static int cmd_ua_next(struct re_printf *pf, void *unused)
 {
+	int err;
+
 	(void)pf;
 	(void)unused;
 
@@ -386,13 +388,13 @@ static int cmd_ua_next(struct re_printf *pf, void *unused)
 
 	le_cur = le_cur->next ? le_cur->next : list_head(uag_list());
 
-	(void)re_fprintf(stderr, "ua: %s\n", ua_aor(list_ledata(le_cur)));
+	err = re_hprintf(pf, "ua: %s\n", ua_aor(list_ledata(le_cur)));
 
 	uag_current_set(list_ledata(le_cur));
 
 	update_callstatus();
 
-	return 0;
+	return err;
 }
 
 
@@ -410,6 +412,32 @@ static int cmd_print_calls(struct re_printf *pf, void *unused)
 }
 
 
+static const char about_fmt[] =
+	".------------------------------------------------------------.\n"
+	"|                      "
+	"\x1b[34;1m" "bare"
+	"\x1b[31;1m" "sip"
+	"\x1b[;m"
+	" %-10s                    |\n"
+	"|                                                            |\n"
+	"| Baresip is a portable and modular SIP User-Agent           |\n"
+	"| with audio and video support                               |\n"
+	"|                                                            |\n"
+	"| License:   BSD                                             |\n"
+	"| Homepage:  https://github.com/alfredh/baresip              |\n"
+	"|                                                            |\n"
+	"'------------------------------------------------------------'\n"
+	;
+
+
+static int about_box(struct re_printf *pf, void *unused)
+{
+	(void)unused;
+
+	return re_hprintf(pf, about_fmt, BARESIP_VERSION);
+}
+
+
 static const struct cmd cmdv[] = {
 
 {"accept",    'a',        0, "Accept incoming call",    cmd_answer           },
@@ -425,6 +453,7 @@ static const struct cmd cmdv[] = {
 {"uanew",     0,    CMD_PRM, "Create User-Agent",       create_ua            },
 {"ausrc",     0,   CMD_IPRM, "Switch audio source",     switch_audio_source  },
 {"auplay",    0,   CMD_IPRM, "Switch audio player",     switch_audio_player  },
+{"about",     0,          0, "About box",               about_box            },
 
 };
 
@@ -950,7 +979,13 @@ static void ua_event_handler(struct ua *ua, enum ua_event ev,
 		/* stop any ringtones */
 		menu.play = mem_deref(menu.play);
 
-		(void)play_file(&menu.play, player, "ringback.wav", -1);
+		if (menu.ringback_disabled) {
+			info("\nRingback disabled\n");
+		}
+		else {
+			(void)play_file(&menu.play, player,
+					"ringback.wav",-1);
+		}
 		break;
 
 	case UA_EVENT_CALL_ESTABLISHED:
@@ -1031,8 +1066,8 @@ static void message_handler(const struct pl *peer, const struct pl *ctype,
 	(void)ctype;
 	(void)arg;
 
-	(void)re_fprintf(stderr, "\r%r: \"%b\"\n", peer,
-			 mbuf_buf(body), mbuf_get_left(body));
+	ui_output(baresip_uis(), "\r%r: \"%b\"\n",
+		  peer, mbuf_buf(body), mbuf_get_left(body));
 
 	(void)play_file(NULL, baresip_player(), "message.wav", 0);
 }
@@ -1047,6 +1082,8 @@ static int module_init(void)
 	 * Read the config values
 	 */
 	conf_get_bool(conf_cur(), "menu_bell", &menu.bell);
+	conf_get_bool(conf_cur(), "ringback_disabled",
+		      &menu.ringback_disabled);
 
 	if (0 == conf_get(conf_cur(), "redial_attempts", &val) &&
 	    0 == pl_strcasecmp(&val, "inf")) {
