@@ -60,8 +60,10 @@ static void notify_handler(struct sip *sip, const struct sip_msg *msg,
 	struct mwi *mwi = arg;
 
 	if (mbuf_get_left(msg->mb)) {
-		ui_output("----- MWI for %s -----\n", ua_aor(mwi->ua));
-		ui_output("%b\n", mbuf_buf(msg->mb), mbuf_get_left(msg->mb));
+		struct ui_sub *uis = baresip_uis();
+		ui_output(uis, "----- MWI for %s -----\n", ua_aor(mwi->ua));
+		ui_output(uis, "%b\n", mbuf_buf(msg->mb),
+			  mbuf_get_left(msg->mb));
 	}
 
 	(void)sip_treply(NULL, sip, msg, 200, "OK");
