@@ -28,8 +28,10 @@ static int module_init(void)
 {
 	int err;
 
-	err  = auplay_register(&auplay, "pulse", pulse_player_alloc);
-	err |= ausrc_register(&ausrc, "pulse", pulse_recorder_alloc);
+	err  = auplay_register(&auplay, baresip_auplayl(),
+			       "pulse", pulse_player_alloc);
+	err |= ausrc_register(&ausrc, baresip_ausrcl(),
+			      "pulse", pulse_recorder_alloc);
 
 	return err;
 }
