@@ -25,12 +25,17 @@ struct vidisp_st {
 	struct vidsz size;              /**< Current size          */
 	enum vidfmt fmt;                /**< Current pixel format  */
 	bool fullscreen;                /**< Fullscreen flag       */
+	struct tmr tmr;
+	Uint32 flags;
 };
 
 
 static struct vidisp *vid;
 
 
+static void event_handler(void *arg);
+
+
 static uint32_t match_fmt(enum vidfmt fmt)
 {
 	switch (fmt) {
@@ -76,10 +81,49 @@ static void sdl_reset(struct vidisp_st *st)
 }
 
 
+static void event_handler(void *arg)
+{
+	struct vidisp_st *st = arg;
+	SDL_Event event;
+
+	tmr_start(&st->tmr, 100, event_handler, st);
+
+	/* NOTE: events must be checked from main thread */
+	while (SDL_PollEvent(&event)) {
+
+		if (event.type == SDL_KEYDOWN) {
+
+			switch (event.key.keysym.sym) {
+
+			case SDLK_f:
+				/* press key 'f' to toggle fullscreen */
+				st->fullscreen = !st->fullscreen;
+				info("sdl: %sable fullscreen mode\n",
+				     st->fullscreen ? "en" : "dis");
+
+				if (st->fullscreen)
+					st->flags |=
+						SDL_WINDOW_FULLSCREEN_DESKTOP;
+				else
+					st->flags &=
+						~SDL_WINDOW_FULLSCREEN_DESKTOP;
+
+				SDL_SetWindowFullscreen(st->window, st->flags);
+				break;
+
+			default:
+				break;
+			}
+		}
+	}
+}
+
+
 static void destructor(void *arg)
 {
 	struct vidisp_st *st = arg;
 
+	tmr_cancel(&st->tmr);
 	sdl_reset(st);
 }
 
@@ -92,7 +136,6 @@ static int alloc(struct vidisp_st **stp, const struct vidisp *vd,
 	int err = 0;
 
 	/* Not used by SDL */
-	(void)prm;
 	(void)dev;
 	(void)resizeh;
 	(void)arg;
@@ -105,6 +148,9 @@ static int alloc(struct vidisp_st **stp, const struct vidisp *vd,
 		return ENOMEM;
 
 	st->vd = vd;
+	st->fullscreen = prm ? prm->fullscreen : false;
+
+	tmr_start(&st->tmr, 100, event_handler, st);
 
 	if (err)
 		mem_deref(st);
@@ -146,11 +192,12 @@ static int display(struct vidisp_st *st, const char *title,
 	}
 
 	if (!st->window) {
-		Uint32 flags = SDL_WINDOW_SHOWN | SDL_WINDOW_INPUT_FOCUS;
 		char capt[256];
 
+		st->flags = SDL_WINDOW_SHOWN | SDL_WINDOW_INPUT_FOCUS;
+
 		if (st->fullscreen)
-			flags |= SDL_WINDOW_FULLSCREEN;
+			st->flags |= SDL_WINDOW_FULLSCREEN_DESKTOP;
 
 		if (title) {
 			re_snprintf(capt, sizeof(capt), "%s - %u x %u",
@@ -165,7 +212,7 @@ static int display(struct vidisp_st *st, const char *title,
 					      SDL_WINDOWPOS_CENTERED,
 					      SDL_WINDOWPOS_CENTERED,
 					      frame->size.w, frame->size.h,
-					      flags);
+					      st->flags);
 		if (!st->window) {
 			warning("sdl: unable to create sdl window: %s\n",
 				SDL_GetError());
