@@ -43,12 +43,14 @@ static int module_init(void)
 	if (err)
 		return err;
 
-	err = vidisp_register(&vidisp, "vidbridge", vidbridge_disp_alloc,
+	err = vidisp_register(&vidisp, baresip_vidispl(),
+			      "vidbridge", vidbridge_disp_alloc,
 			      NULL, vidbridge_disp_display, 0);
 	if (err)
 		return err;
 
-	err = vidsrc_register(&vidsrc, "vidbridge", vidbridge_src_alloc, NULL);
+	err = vidsrc_register(&vidsrc, baresip_vidsrcl(),
+			      "vidbridge", vidbridge_src_alloc, NULL);
 	if (err)
 		return err;
 
