@@ -362,7 +362,7 @@ int account_alloc(struct account **accp, const char *sipaddr)
 	pl_set_str(&pl, acc->buf);
 	err = sip_addr_decode(&acc->laddr, &pl);
 	if (err) {
-		warning("account: invalid SIP address: `%r'\n", &pl);
+		warning("account: error parsing SIP address: '%r'\n", &pl);
 		goto out;
 	}
 
