@@ -77,7 +77,7 @@ int main(int argc, char *argv[])
 	size_t i;
 	int err;
 
-	(void)re_fprintf(stderr, "baresip v%s"
+	(void)re_fprintf(stdout, "baresip v%s"
 			 " Copyright (C) 2010 - 2017"
 			 " Alfred E. Heggestad et al.\n",
 			 BARESIP_VERSION);
