@@ -8,20 +8,18 @@
 #include "core.h"
 
 
-static struct list mencl = LIST_INIT;
-
-
 /**
  * Register a new Media encryption module
  *
- * @param menc Media encryption module
+ * @param mencl List of Media-encryption modules
+ * @param menc  Media encryption module
  */
-void menc_register(struct menc *menc)
+void menc_register(struct list *mencl, struct menc *menc)
 {
-	if (!menc)
+	if (!mencl || !menc)
 		return;
 
-	list_append(&mencl, &menc->le, menc);
+	list_append(mencl, &menc->le, menc);
 
 	info("mediaenc: %s\n", menc->id);
 }
@@ -44,15 +42,19 @@ void menc_unregister(struct menc *menc)
 /**
  * Find a Media Encryption module by name
  *
- * @param id Name of the Media Encryption module to find
+ * @param mencl List of Media-encryption modules
+ * @param id    Name of the Media Encryption module to find
  *
  * @return Matching Media Encryption module if found, otherwise NULL
  */
-const struct menc *menc_find(const char *id)
+const struct menc *menc_find(const struct list *mencl, const char *id)
 {
 	struct le *le;
 
-	for (le = mencl.head; le; le = le->next) {
+	if (!mencl)
+		return NULL;
+
+	for (le = mencl->head; le; le = le->next) {
 		struct menc *me = le->data;
 
 		if (0 == str_casecmp(id, me->id))
