@@ -8,23 +8,22 @@
 #include "core.h"
 
 
-struct modapp {
-	struct mod *mod;
-	struct le le;
-};
-
-
-static struct list modappl;
-
-
-static void modapp_destructor(void *arg)
+/*
+ * Append module extension, if not exist
+ *
+ * input:    foobar
+ * output:   foobar.so
+ *
+ */
+static void append_extension(char *buf, size_t sz, const char *name)
 {
-	struct modapp *modapp = arg;
-	const struct mod_export *me = mod_export(modapp->mod);
-	if (me)
-		debug("module: unloading app %s\n", me->name);
-	list_unlink(&modapp->le);
-	mem_deref(modapp->mod);
+	if (0 == re_regex(name, str_len(name), "[^.]+"MOD_EXT, NULL)) {
+
+		str_ncpy(buf, name, sz);
+	}
+	else {
+		re_snprintf(buf, sz, "%s"MOD_EXT, name);
+	}
 }
 
 
@@ -119,20 +118,20 @@ static int module_tmp_handler(const struct pl *val, void *arg)
 
 static int module_app_handler(const struct pl *val, void *arg)
 {
-	struct modapp *modapp;
+	struct mod *mod = NULL;
+	const struct mod_export *me;
 
 	debug("module: loading app %r\n", val);
 
-	modapp = mem_zalloc(sizeof(*modapp), modapp_destructor);
-	if (!modapp)
-		return ENOMEM;
-
-	if (load_module(&modapp->mod, arg, val)) {
-		mem_deref(modapp);
+	if (load_module(&mod, arg, val)) {
 		return 0;
 	}
 
-	list_prepend(&modappl, &modapp->le, modapp);
+	me = mod_export(mod);
+	if (0 != str_casecmp(me->type, "application")) {
+		warning("module_app %r should be type application (%s)\n",
+			val, me->type);
+	}
 
 	return 0;
 }
@@ -167,7 +166,20 @@ int module_init(const struct conf *conf)
 
 void module_app_unload(void)
 {
-	list_flush(&modappl);
+	struct le *le = list_tail(mod_list());
+
+	/* unload in reverse order */
+	while (le) {
+		struct mod *mod = le->data;
+		const struct mod_export *me = mod_export(mod);
+
+		le = le->prev;
+
+		if (me && 0 == str_casecmp(me->type, "application")) {
+			debug("module: unloading app %s\n", me->name);
+			mem_deref(mod);
+		}
+	}
 }
 
 
@@ -183,3 +195,64 @@ int module_preload(const char *module)
 
 	return load_module(NULL, &path, &name);
 }
+
+
+/**
+ * Load a module by name or by filename
+ *
+ * @param name Module name incl/excl extension, excluding module path
+ *
+ * @return 0 if success, otherwise errorcode
+ *
+ * example:    "foo"
+ * example:    "foo.so"
+ */
+int module_load(const char *name)
+{
+	char filename[256];
+	struct pl path, pl_name;
+	int err;
+
+	if (!str_isset(name))
+		return EINVAL;
+
+	append_extension(filename, sizeof(filename), name);
+
+	pl_set_str(&pl_name, filename);
+
+	if (conf_get(conf_cur(), "module_path", &path))
+		pl_set_str(&path, ".");
+
+	err = load_module(NULL, &path, &pl_name);
+
+	return err;
+}
+
+
+/**
+ * Unload a module by name or by filename
+ *
+ * @param name module name incl/excl extension, excluding module path
+ *
+ * example:   "foo"
+ * example:   "foo.so"
+ */
+void module_unload(const char *name)
+{
+	char filename[256];
+	struct mod *mod;
+
+	if (!str_isset(name))
+		return;
+
+	append_extension(filename, sizeof(filename), name);
+
+	mod = mod_find(filename);
+	if (mod) {
+		info("unloading module: %s\n", filename);
+		mem_deref(mod);
+		return;
+	}
+
+	info("ERROR: Module %s is not currently loaded\n", name);
+}
