@@ -52,6 +52,12 @@ static void check_rtp_handler(void *arg)
 		debug("stream: last \"%s\" RTP packet: %d milliseconds\n",
 		      sdp_media_name(strm->sdp), diff_ms);
 
+		/* check for large jumps in time */
+		if (diff_ms > (3600 * 1000)) {
+			strm->ts_last = 0;
+			return;
+		}
+
 		if (diff_ms > (int)strm->rtp_timeout_ms) {
 
 			info("stream: no %s RTP packets received for"
@@ -200,8 +206,8 @@ static void handle_rtp(struct stream *s, const struct rtp_header *hdr,
 }
 
 
-static void rtp_recv(const struct sa *src, const struct rtp_header *hdr,
-		     struct mbuf *mb, void *arg)
+static void rtp_handler(const struct sa *src, const struct rtp_header *hdr,
+			struct mbuf *mb, void *arg)
 {
 	struct stream *s = arg;
 	bool flush = false;
@@ -289,6 +295,8 @@ static void rtcp_handler(const struct sa *src, struct rtcp_msg *msg, void *arg)
 		if (s->cfg.rtp_stats)
 			call_set_xrtpstat(s->call);
 
+		ua_event(call_get_ua(s->call), UA_EVENT_CALL_RTCP, s->call,
+			 "%s", sdp_media_name(stream_sdpmedia(s)));
 		break;
 	}
 }
@@ -307,7 +315,7 @@ static int stream_sock_alloc(struct stream *s, int af)
 
 	err = rtp_listen(&s->rtp, IPPROTO_UDP, &laddr,
 			 s->cfg.rtp_ports.min, s->cfg.rtp_ports.max,
-			 s->rtcp, rtp_recv, rtcp_handler, s);
+			 s->rtcp, rtp_handler, rtcp_handler, s);
 	if (err) {
 		warning("stream: rtp_listen failed: af=%s ports=%u-%u"
 			" (%m)\n", net_af2name(af),
@@ -717,3 +725,9 @@ int stream_print(struct re_printf *pf, const struct stream *s)
 			  s->metric_tx.cur_bitrate,
 			  s->metric_rx.cur_bitrate);
 }
+
+
+const struct rtcp_stats *stream_rtcp_stats(const struct stream *strm)
+{
+	return strm ? &strm->rtcp_stats : NULL;
+}
