@@ -1632,64 +1632,6 @@ struct tls *uag_tls(void)
 }
 
 
-/**
- * Get the name of the User-Agent event
- *
- * @param ev User-Agent event
- *
- * @return Name of the event
- */
-const char *uag_event_str(enum ua_event ev)
-{
-	switch (ev) {
-
-	case UA_EVENT_REGISTERING:          return "REGISTERING";
-	case UA_EVENT_REGISTER_OK:          return "REGISTER_OK";
-	case UA_EVENT_REGISTER_FAIL:        return "REGISTER_FAIL";
-	case UA_EVENT_UNREGISTERING:        return "UNREGISTERING";
-	case UA_EVENT_SHUTDOWN:             return "SHUTDOWN";
-	case UA_EVENT_EXIT:                 return "EXIT";
-	case UA_EVENT_CALL_INCOMING:        return "CALL_INCOMING";
-	case UA_EVENT_CALL_RINGING:         return "CALL_RINGING";
-	case UA_EVENT_CALL_PROGRESS:        return "CALL_PROGRESS";
-	case UA_EVENT_CALL_ESTABLISHED:     return "CALL_ESTABLISHED";
-	case UA_EVENT_CALL_CLOSED:          return "CALL_CLOSED";
-	case UA_EVENT_CALL_TRANSFER_FAILED: return "TRANSFER_FAILED";
-	case UA_EVENT_CALL_DTMF_START:      return "CALL_DTMF_START";
-	case UA_EVENT_CALL_DTMF_END:        return "CALL_DTMF_END";
-	default: return "?";
-	}
-}
-
-
-/**
- * Get the current SIP socket file descriptor for a User-Agent
- *
- * @param ua User-Agent
- *
- * @return File descriptor, or -1 if not available
- */
-int ua_sipfd(const struct ua *ua)
-{
-	struct le *le;
-
-	if (!ua)
-		return -1;
-
-	for (le = ua->regl.head; le; le = le->next) {
-
-		struct reg *reg = le->data;
-		int fd;
-
-		fd = reg_sipfd(reg);
-		if (fd != -1)
-			return fd;
-	}
-
-	return -1;
-}
-
-
 /**
  * Find the correct UA from the contact user
  *
